<?php

/* * *************************************************************
 *  Copyright notice
 *
 *  (c) 2013-2017 - Dirk Wildt <http://wildt.at.die-netzmacher.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 * ************************************************************* */

/**
 * Plugin 'Organiser Installer' for the 'org_installer' extension.
 *
 * @author    Dirk Wildt <http://wildt.at.die-netzmacher.de>
 * @package    TYPO3
 * @subpackage    tx_orginstaller
 * @version 6.0.0
 * @since 3.0.0
 */
class tx_orginstaller_pi1_consolidate
{

  public $prefixId = 'tx_orginstaller_pi1_consolidate';                // Same as class name
  public $scriptRelPath = 'pi1/class.tx_orginstaller_pi1_consolidate.php';  // Path to this script relative to the extension dir.
  public $extKey = 'org_installer';                      // The extension key.
  public $pObj = null;
  private $powermailVersionAppendix = null;

  /*   * *********************************************
   *
   * Main
   *
   * ******************************************** */

  /**
   * main( )
   *
   * @return	void
   * @access public
   * @version 3.0.0
   * @since   3.0.0
   */
  public function main()
  {
    $this->pObj->arrReport[] = '
      <h2>
       ' . $this->pObj->pi_getLL( 'consolidate_header' ) . '
      </h2>';

    $this->pageOrg();
    $this->pageOrgCalCaddy();
    $this->pageOrgData();
    $this->pageOrgDocumentsCaddy();

    $installCase = $this->pObj->markerArray[ '###INSTALL_CASE###' ];
    switch( $installCase )
    {
      case( 'install_org' ):
        return;
      case( 'install_automaketemplate' ):
        // follow the workflow
        break;
      case( 'install_start' ):
        return;
      default:
        $prompt = __METHOD__ . ' #' . __LINE__ . ': Undefined value in switch: "' . $installCase . '"';
        die( $prompt );
    }

    $this->pageOrgLibraryHeaderLogo();
  }

  /*   * *********************************************
   *
   * pages
   *
   * ******************************************** */

  /**
   * pageOrg( )
   *
   * @return	void
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrg()
  { 
   $records = array();
    $pageTitle = $GLOBALS[ 'TSFE' ]->page[ 'title' ];

    // Update page properties
    $records = $this->pageOrg_properties();
    $this->sqlUpdatePages( $records, $pageTitle );

    // Hide the installer plugin
    $records = $this->pageOrg_pluginInstallHide();
    $this->sqlUpdatePlugin( $records, $pageTitle );

    // Hide the TypoScript template
    $this->pageOrg_typoscriptOtherHide();
    $this->sqlUpdateTyposcriptOtherHide();
  }

  /**
   * pageOrg_pluginInstallHide( )
   *
   * @return	array		$records : the plugin record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrg_pluginInstallHide()
  {
    $records = null;

    $uid = $this->pObj->cObj->data[ 'uid' ];
    $header = $this->pObj->cObj->data[ 'header' ];

    $records[ $uid ][ 'header' ] = $header;
    $records[ $uid ][ 'hidden' ] = 1;

    return $records;
  }

  /**
   * pageOrg_properties( )
   *
   * @return	array		$records    : the TypoScript record
   * @access private
   * @version 8.0.0
   * @since   3.0.0
   */
  private function pageOrg_properties()
  {
    $records = null;

    $uid = $GLOBALS[ 'TSFE' ]->id;
    $groupUid = $this->pObj->markerArray[ '###GROUP_UID###' ];
    $groupTitle = $this->pObj->markerArray[ '###GROUP_TITLE###' ];

    $installCase = $this->pObj->markerArray[ '###INSTALL_CASE###' ];
    switch( $installCase )
    {
      case( 'install_automaketemplate' ):
        $records[ $uid ][ 'is_siteroot' ] = 1;
        $records[ $uid ][ 'nav_title' ] = $this->pObj->pi_getLL( 'pageQuickshop_titleNav' );
        break;
      case( 'install_org' ):
        $records[ $uid ][ 'is_siteroot' ] = 0;
        $records[ $uid ][ 'nav_title' ] = null;
        break;
      case( 'install_start' ):
        $records[ $uid ][ 'backend_layout' ] = 'start__bronze_01';
        $records[ $uid ][ 'backend_layout_next_level' ] = 'start__bronze_01';
        $records[ $uid ][ 'is_siteroot' ] = 1;
        $records[ $uid ][ 'nav_title' ] = $this->pObj->pi_getLL( 'pageQuickshop_titleNav' );
        break;
      default:
        $prompt = __METHOD__ . ' #' . __LINE__ . ': Undefined value in switch: "' . $installCase . '"';
        die( $prompt );
    }

    $records[ $uid ][ 'title' ] = $this->pObj->pi_getLL( 'pageOrg_title' );
    $records[ $uid ][ 'doktype' ] = 1; // 1: page
    $records[ $uid ][ 'module' ] = null;
    $records[ $uid ][ 'nav_hide' ] = 0;
    $records[ $uid ][ 'TSconfig' ] = '

// ORGANISER INSTALLER at ' . date( 'Y-m-d G:i:s' ) . ' -- BEGIN

  /////////////////////////////////////
  //
  // INDEX
  //
  // TCEMAIN.permissions


  // TCEMAIN.permissions
TCEMAIN {
  permissions {
    // ' . $groupUid . ': ' . $groupTitle . '
    groupid = ' . $groupUid . '
    group   = show,edit,delete,new,editcontent
  }
}
  // TCEMAIN.permissions

// ORGANISER INSTALLER at ' . date( 'Y-m-d G:i:s' ) . ' -- END

';
    $records[ $uid ][ 'TSconfig' ] = $this->zz_replacePageUids( $records[ $uid ][ 'TSconfig' ] );

    return $records;
  }

  /**
   * pageOrg_typoscriptOtherHide( )
   *
   * @return	array		$record : the TypoScript record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrg_typoscriptOtherHide()
  {
    // Do nothing
  }

  /**
   * pageOrgCalCaddy( )
   *
   * @return	void
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrgCalCaddy()
  {
    $records = array();
    $pageTitle = $this->pObj->pi_getLL( 'pageOrgCalCaddy_title' );

    // 160720, dwildt, 3-
//    // Update the jss script
//    $records = $this->pageOrgCalCaddy_contentJss();
//    $this->sqlUpdateContent( $records, $pageTitle );
    // Update the powermail plugin
    $records = $this->pageOrgCalCaddy_pluginPowermail();
    $this->sqlUpdatePlugin( $records, $pageTitle );

    // Update the caddy plugin
    $records = $this->pageOrgCalCaddy_pluginCaddy();
    $this->sqlUpdatePlugin( $records, $pageTitle );

    // Update the TypoScript
    $records = $this->pageOrgCalCaddy_typoscript();
    $this->sqlUpdateTyposcript( $records, $pageTitle );
  }

  /**
   * pageOrgCalCaddy_contentJss( )
   *
   * @return	array		$records : the plugin record
   * @access private
   * @version 3.0.4
   * @since   3.0.4
   */
  private function pageOrgCalCaddy_contentJss()
  {
    $records = null;
    $uid = $this->pObj->arr_contentUids[ 'content_pageOrgCalCaddy_header' ];

    // values
    $llHeader = $this->pObj->pi_getLL( 'content_pageOrgCalCaddy_header' );
    // values

    $pmFieldsetUid = $this->pObj->powermailPageOrgCaddy->getValue( 'record_pm_fSets_title_deliveryAddress' );
    switch( true )
    {
      case( $this->pObj->powermailVersionInt < 1000000 ):
        $prompt = 'ERROR: unexpected result<br />
          powermail version is below 1.0.0: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
        die( $prompt );
        break;
      case( $this->pObj->powermailVersionInt < 2000000 ):
        $pmFieldsetHtmlId = 'tx-powermail-pi1_fieldset_' . $pmFieldsetUid;
        break;
      case( $this->pObj->powermailVersionInt < 4000000 ):
        $pmFieldsetHtmlId = 'powermail_fieldset_' . $pmFieldsetUid;
        break;
      case( $this->pObj->powermailVersionInt >= 4000000 ):
      default:
        $prompt = 'ERROR: unexpected result<br />
          powermail version is higher than 3.x: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
        die( $prompt );
        break;
    }

    // 160720, dwildt, 2-
//    $jssScript = $this->pObj->pi_getLL( 'content_pageOrgCalCaddy_bodytext' );
//    $jssScript = str_replace( '###POWERMAIL_FIELDSET_DELIVERYORDER_ADDRESS###', $pmFieldsetHtmlId, $jssScript );


    $records[ $uid ][ 'header' ] = $llHeader;
    // 160720, dwildt, 1-
//    $records[ $uid ][ 'bodytext' ] = $jssScript;
    $records[ $uid ][ 'hidden' ] = 1;

    return $records;
  }

  /**
   * pageOrgCalCaddy_pluginCaddy( )
   *
   * @return	array		$records : the plugin record
   * @access private
	 * @internal #i0059
   * @version 8.0.19
   * @since   3.0.0
   */
  private function pageOrgCalCaddy_pluginCaddy()
  {
    $records = null;
    $uid = $this->pObj->arr_pluginUids[ 'pluginCaddyPageOrgCaddy_header' ];
    $pmX = $this->powermailVersionAppendix();

    // values
    $llHeader = $this->pObj->pi_getLL( 'pluginCaddyPageOrgCaddy_header' );
    // values

    $records[ $uid ][ 'header' ] = $llHeader;
    $records[ $uid ][ 'pi_flexform' ] = null .
            '<?xml version="1.0" encoding="utf-8" standalone="yes" ?>
<T3FlexForms>
    <data>
        <sheet index="note">
            <language index="lDEF">
                <field index="note">
                    <value index="vDEF">'
            . $this->pObj->pi_getLL( 'pluginCaddyPageOrgCaddy_note_' . $pmX ) .
            '</value>
                </field>
            </language>
        </sheet>
        <sheet index="origin">
            <language index="lDEF">
                <field index="order">
                    <value index="vDEF">3972</value>
                </field>
                <field index="invoice">
                    <value index="vDEF">83</value>
                </field>
                <field index="deliveryorder">
                    <value index="vDEF">216</value>
                </field>
                <field index="min">
                    <value index="vDEF">1</value>
                </field>
                <field index="max">
                    <value index="vDEF">100</value>
                </field>
            </language>
        </sheet>
        <sheet index="email">
            <language index="lDEF">
                <field index="customerEmail">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgCalCaddy_title', 'record_pm_field_title_email' ) .
            '</value>
                </field>
                <field index="termsMode">
                    <value index="vDEF">all</value>
                </field>
                <field index="revocationMode">
                    <value index="vDEF">all</value>
                </field>
                <field index="invoiceMode">
                    <value index="vDEF">all</value>
                </field>
                <field index="deliveryorderMode">
                    <value index="vDEF">all</value>
                </field>
                <field index="orderconfirmationMode">
                    <value index="vDEF">all</value>
                </field>
            </language>
        </sheet>
        <sheet index="invoice">
            <language index="lDEF">
                <field index="company">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgCalCaddy_title', 'record_pm_field_title_companyBilling' ) .
            '</value>
                </field>
                <field index="firstName">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgCalCaddy_title', 'record_pm_field_title_firstnameBilling' ) .
            '</value>
                </field>
                <field index="lastName">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgCalCaddy_title', 'record_pm_field_title_surnameBilling' ) .
            '</value>
                </field>
                <field index="address">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgCalCaddy_title', 'record_pm_field_title_streetBilling' ) .
            '</value>
                </field>
                <field index="zip">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgCalCaddy_title', 'record_pm_field_title_zipBilling' ) .
            '</value>
                </field>
                <field index="city">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgCalCaddy_title', 'record_pm_field_title_locationBilling' ) .
            '</value>
                </field>
                <field index="country">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgCalCaddy_title', 'record_pm_field_title_countryBilling' ) .
            '</value>
                </field>
            </language>
        </sheet>
        <sheet index="deliveryorder">
            <language index="lDEF">
                <field index="company">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgCalCaddy_title', 'record_pm_field_title_companyDelivery' ) .
            '</value>
                </field>
                <field index="firstName">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgCalCaddy_title', 'record_pm_field_title_firstnameDelivery' ) .
            '</value>
                </field>
                <field index="lastName">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgCalCaddy_title', 'record_pm_field_title_surnameDelivery' ) .
            '</value>
                </field>
                <field index="address">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgCalCaddy_title', 'record_pm_field_title_streetDelivery' ) .
            '</value>
                </field>
                <field index="zip">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgCalCaddy_title', 'record_pm_field_title_zipDelivery' ) .
            '</value>
                </field>
                <field index="city">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgCalCaddy_title', 'record_pm_field_title_locationDelivery' ) .
            '</value>
                </field>
                <field index="country">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgCalCaddy_title', 'record_pm_field_title_countryDelivery' ) .
            '</value>
                </field>
            </language>
        </sheet>
        <sheet index="paths">
            <language index="lDEF">
                <field index="terms">
                    <value index="vDEF">typo3conf/ext/org/Resources/Public/Files/typo3-organiser_for_caddy.pdf</value>
                </field>
                <field index="revocation">
                    <value index="vDEF">typo3conf/ext/org/Resources/Public/Files/typo3-organiser_for_caddy.pdf</value>
                </field>
                <field index="invoice">
                    <value index="vDEF">typo3conf/ext/org/Resources/Public/Files/typo3-organiser_for_caddy.pdf</value>
                </field>
                <field index="deliveryorder">
                    <value index="vDEF">typo3conf/ext/org/Resources/Public/Files/typo3-organiser_for_caddy.pdf</value>
                </field>
                <field index="orderconfirmation">
                    <value index="vDEF">typo3conf/ext/org/Resources/Public/Files/typo3-organiser_for_caddy.pdf</value>
                </field>
            </language>
        </sheet>
        <sheet index="debit">
            <language index="lDEF">
                <field index="owner">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgCalCaddy_title', 'record_pm_field_title_accountowner' ) .
						'</value>
                </field>
                <field index="bic">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgCalCaddy_title', 'record_pm_field_title_bic' ) .
						'</value>
                </field>
                <field index="iban">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgCalCaddy_title', 'record_pm_field_title_iban' ) .
						'</value>
                </field>
            </language>
        </sheet>
    </data>
</T3FlexForms>
';

    return $records;
  }

  /**
   * pageOrgCalCaddy_pluginPowermail( )
   *
   * @return	array		$records : the plugin record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrgCalCaddy_pluginPowermail()
  {
    $records = null;

    switch( true )
    {
      case( $this->pObj->powermailVersionInt < 1000000 ):
        $prompt = 'ERROR: unexpected result<br />
          powermail version is below 1.0.0: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
        die( $prompt );
        break;
      case( $this->pObj->powermailVersionInt < 2000000 ):
        $records = $this->pageOrgCalCaddy_pluginPowermail1x();
        break;
      case( $this->pObj->powermailVersionInt < 4000000 ):
        $records = $this->pageOrgCalCaddy_pluginPowermail2x();
        break;
      case( $this->pObj->powermailVersionInt >= 4000000 ):
      default:
        $prompt = 'ERROR: unexpected result<br />
          powermail version is higher than 3.x: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
        die( $prompt );
        break;
    }

    return $records;
  }

  /**
   * pageOrgCalCaddy_pluginPowermail1x( )
   *
   * @return	array		$records : the plugin record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrgCalCaddy_pluginPowermail1x()
  {
    $records = null;
    $uid = $this->pObj->arr_pluginUids[ 'pluginPowermailPageOrgCaddy_header' ];

    // values
    $llHeader = $this->pObj->pi_getLL( 'pluginPowermailPageOrgCaddy_header' );
    $uidEmail = $this->pObj->powermailPageOrgCaddy->getValue( 'record_pm_field_title_email' );
    $customerEmail = 'uid' . $uidEmail;
    $uidFirstname = $this->pObj->powermailPageOrgCaddy->getValue( 'record_pm_field_title_firstnameBilling' );
    $uidSurname = $this->pObj->powermailPageOrgCaddy->getValue( 'record_pm_field_title_surnameBilling' );
    $customerName = 'uid' . $uidFirstname . ',uid' . $uidSurname;
    // values

    $records[ $uid ][ 'header' ] = $llHeader;
    $records[ $uid ][ 'tx_powermail_sender' ] = $customerEmail;
    $records[ $uid ][ 'tx_powermail_sendername' ] = $customerName;

    return $records;
  }

  /**
   * pageOrgCalCaddy_pluginPowermail2x( )
   *
   * @return	array		$records : the plugin record
   * @access private
	 * @internal #i0071: settings.flexform.main.moresteps = 1
   * @version 8.0.15
   * @since   3.0.0
   */
  private function pageOrgCalCaddy_pluginPowermail2x()
  {
    $records = null;
    $uid = $this->pObj->arr_pluginUids[ 'pluginPowermailPageOrgCaddy_header' ];

    $llHeader = $this->pObj->pi_getLL( 'pluginPowermailPageOrgCaddy_header' );
    $uidForm = $this->pObj->powermailPageOrgCaddy->getValue( 'record_pm_form_title_pageOrgCalCaddy' );
    $receiverSubject = $this->pObj->pi_getLL( 'pluginPowermailPageOrgCaddy_subject_r2x' );
    $receiverBody = htmlspecialchars( $this->pObj->pi_getLL( 'pluginPowermailPageOrgCaddy_body_r2x' ) );
    // #i0016, 140926, dwildt, 3-
//    list( $name, $domain) = explode( '@', $this->pObj->markerArray['###MAIL_DEFAULT_RECIPIENT###'] );
//    unset( $name );
//    $senderEmail      = 'noreply@' . $domain;
    // #i0016, 140926, dwildt, 3-
//    $providerEmail = $this->pObj->markerArray[ '###MAIL_DEFAULT_RECIPIENT###' ];
//    list( $name, $domain) = explode( '@', $providerEmail );
//    unset( $name );
//    $noreplyEmail = 'noreply@' . $domain;
    $senderEmail = $this->pObj->markerArray[ '###MAIL_DEFAULT_RECIPIENT###' ];
    $senderSubject = $this->pObj->pi_getLL( 'pluginPowermailPageOrgCaddy_subject_s2x' );
    $senderBody = htmlspecialchars( $this->pObj->pi_getLL( 'pluginPowermailPageOrgCaddy_body_s2x' ) );
    $thxBody = htmlspecialchars( $this->pObj->pi_getLL( 'pluginPowermailPageOrgCaddy_thanks2x' ) );

    $records[ $uid ][ 'header' ] = $llHeader;
    $records[ $uid ][ 'pi_flexform' ] = null .
            '<?xml version="1.0" encoding="utf-8" standalone="yes" ?>
<T3FlexForms>
    <data>
        <sheet index="main">
            <language index="lDEF">
                <field index="settings.flexform.main.form">
                    <value index="vDEF">' . $uidForm . '</value>
                </field>
                <field index="settings.flexform.main.confirmation">
                    <value index="vDEF">1</value>
                </field>
                <field index="settings.flexform.main.moresteps">
                    <value index="vDEF">1</value>
                </field>
            </language>
        </sheet>
        <sheet index="receiver">
            <language index="lDEF">
                <field index="settings.flexform.receiver.name">
                    <value index="vDEF">{billingaddressfirstname} {billingaddresslastname}</value>
                </field>
                <field index="settings.flexform.receiver.email">
                    <value index="vDEF">' . $senderEmail . '</value>
                </field>
                <field index="settings.flexform.receiver.subject">
                    <value index="vDEF">' . $receiverSubject . '</value>
                </field>
                <field index="settings.flexform.receiver.body">
                    <value index="vDEF">' . $receiverBody . '</value>
                    <value index="_TRANSFORM_vDEF.vDEFbase">' . $receiverBody . '</value>
                </field>
            </language>
        </sheet>
        <sheet index="sender">
            <language index="lDEF">
                <field index="settings.flexform.sender.name">
                    <value index="vDEF">Organiser</value>
                </field>
                <field index="settings.flexform.sender.email">
                    <value index="vDEF">' . $senderEmail . '</value>
                </field>
                <field index="settings.flexform.sender.subject">
                    <value index="vDEF">' . $senderSubject . '</value>
                </field>
                <field index="settings.flexform.sender.body">
                    <value index="vDEF">' . $senderBody . '</value>
                    <value index="_TRANSFORM_vDEF.vDEFbase">' . $senderBody . '</value>
                </field>
            </language>
        </sheet>
        <sheet index="thx">
            <language index="lDEF">
                <field index="settings.flexform.thx.body">
                    <value index="vDEF">' . $thxBody . '</value>
                    <value index="_TRANSFORM_vDEF.vDEFbase">' . $thxBody . '</value>
                </field>
                <field index="settings.flexform.thx.redirect">
                    <value index="vDEF"></value>
                </field>
            </language>
        </sheet>
    </data>
</T3FlexForms>';

    return $records;
  }

  /**
   * pageOrgCalCaddy_typoscript( )
   *
   * @return	array		$records    : the TypoScript record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrgCalCaddy_typoscript()
  {
    $records = null;

    $pmX = $this->powermailVersionAppendix();
    switch( true )
    {
      case( $pmX == '1x' ):
        $records = $this->pageOrgCalCaddy_typoscript1x();
        break;
      case( $pmX == '2x' ):
        $records = $this->pageOrgCalCaddy_typoscript2x();
        break;
      default:
        $prompt = 'ERROR: unexpected result<br />
          powermail version is neither 1x nor 2x. Internal: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
        die( $prompt );
        break;
    }

    unset( $pmX );

    return $records;
  }

  /**
   * pageOrgCalCaddy_typoscript1x( )
   *
   * @return	array		$records    : the TypoScript record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrgCalCaddy_typoscript1x()
  {
    $records = null;

    $title = 'pageOrgCalCaddy_title';
    $uid = $this->pObj->arr_tsUids[ $title ];

    $strUid = sprintf( '%03d', $uid );
    $llTitle = strtolower( $this->pObj->pi_getLL( $title ) );
    $llTitle = str_replace( ' ', null, $llTitle );
    $llTitle = '+page_' . $llTitle . '_' . $strUid;

    list( $noreply, $domain ) = explode( '@', $this->pObj->markerArray[ '###MAIL_DEFAULT_RECIPIENT###' ] );
    $noreply = 'noreply@' . $domain;


    $records[ $uid ][ 'title' ] = $llTitle;
    $records[ $uid ][ 'constants' ] = '
  /////////////////////////////////////////
  //
  // INDEX
  //
  // plugin.caddy
  // plugin.powermail



//  Not needed: Is included at the root page
//
//  /////////////////////////////////////////
//  //
//  // plugin.caddy
//
//plugin.caddy {
//  pages {
//    caddy       = ' . $this->pObj->arr_pageUids[ 'pageOrgCalCaddy_title' ] . '
//    caddymini   = ' . $this->pObj->arr_pageUids[ 'pageOrgCalCaddyCaddymini_title' ] . '
//    revocation  = ' . $this->pObj->arr_pageUids[ 'pageOrgCalRevocation_title' ] . '
//    shop        = ' . $this->pObj->arr_pageUids[ 'pageOrg_title' ] . '
//    terms       = ' . $this->pObj->arr_pageUids[ 'pageOrgCalTerms_title' ] . '
//  }
//}
//  // plugin.caddy



  /////////////////////////////////////////
  //
  // plugin.powermail

plugin.powermail {
  js {
    toHeader = 1
  }
}
  // plugin.powermail

';

    $records[ $uid ][ 'config' ] = '
plugin.tx_powermail_pi1 {
  email {
    sender_mail {
      sender {
        name {
          value = Organiser
        }
        email {
          value = ' . $noreply . '
        }
      }
    }
  }
  _LOCAL_LANG {
    default {
      locallangmarker_confirmation_submit = Test Organiser without commitment!
    }
    de {
      locallangmarker_confirmation_submit = Organiser unverbindlich testen!
    }
  }
}';

    $installCase = $this->pObj->markerArray[ '###INSTALL_CASE###' ];
    switch( $installCase )
    {
      case( 'install_automaketemplate' ):
        $records[ $uid ][ 'config' ] = $records[ $uid ][ 'config' ] . '

  // Don\'t display the mini caddy
page.10.subparts.menue.10 >
';
        break;
      case( 'install_org' ):
        // Do nothing
        break;
      case( 'install_start' ):
        // Do nothing
        break;
      default:
        $prompt = __METHOD__ . ' #' . __LINE__ . ': Undefined value in switch: "' . $installCase . '"';
        die( $prompt );
    }

    return $records;
  }

  /**
   * pageOrgCalCaddy_typoscript2x( )
   *
   * @return	array		$records    : the TypoScript record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrgCalCaddy_typoscript2x()
  {
    $records = null;

    $title = 'pageOrgCalCaddy_title';
    $uid = $this->pObj->arr_tsUids[ $title ];

    $strUid = sprintf( '%03d', $uid );
    $llTitle = strtolower( $this->pObj->pi_getLL( $title ) );
    $llTitle = str_replace( ' ', null, $llTitle );
    $llTitle = '+page_' . $llTitle . '_' . $strUid;

    $records[ $uid ][ 'title' ] = $llTitle;
    $records[ $uid ][ 'constants' ] = '
  /////////////////////////////////////////
  //
  // INDEX
  //
  // plugin.caddy
  // plugin.tx_powermail


//  Not needed: Is included at the root page
//
//  /////////////////////////////////////////
//  //
//  // plugin.caddy
//
//plugin.caddy {
//  pages {
//    caddy       = ' . $this->pObj->arr_pageUids[ 'pageOrgCalCaddy_title' ] . '
//    caddymini   = ' . $this->pObj->arr_pageUids[ 'pageOrgCalCaddyCaddymini_title' ] . '
//    revocation  = ' . $this->pObj->arr_pageUids[ 'pageOrgCalRevocation_title' ] . '
//    shop        = ' . $this->pObj->arr_pageUids[ 'pageOrg_title' ] . '
//    terms       = ' . $this->pObj->arr_pageUids[ 'pageOrgCalTerms_title' ] . '
//  }
//}
//  // plugin.caddy


  /////////////////////////////////////////
  //
  // plugin.caddy

plugin.caddy {
  deliveryaddress {
    includescript = 1
    powermail {
      debug = 0
    }
  }
  // 170408, dwildt, -
//  powermail {
//    tabs {
//      debug = 0
//      id {              
//        tab01 = tab_' . $this->pObj->powermailPageOrgCaddy->getValue( 'record_pm_fSets_title_billingAddress' ) . '
//        tab02 = tab_' . $this->pObj->powermailPageOrgCaddy->getValue( 'record_pm_fSets_title_deliveryAddress' ) . '
//        tab03 = tab_' . $this->pObj->powermailPageOrgCaddy->getValue( 'record_pm_fSets_title_contactData' ) . '
//        tab04 = tab_' . $this->pObj->powermailPageOrgCaddy->getValue( 'record_pm_fSets_title_order' ) . '
//      }
//      includescript = 1
//    }
//  }
}
  // plugin.caddy



  /////////////////////////////////////////
  //
  // plugin.tx_powermail

plugin.tx_powermail {
  settings {
    javascript {
        // We take jQuery from tx_browser_pi1 or from T3jQuery (recommended)
      powermailJQuery =
      powermailJQueryUi =
    }
  }
}
  // plugin.tx_powermail

';
    $records[ $uid ][ 'constants' ] = $this->zz_replacePageUids( $records[ $uid ][ 'constants' ] );

    $records[ $uid ][ 'config' ] = '
plugin.tx_powermail {
  _LOCAL_LANG {
    default {
        // Next button will be empty in Powermail 2.x
      //confirmation_next = Order without commitment
    }
    de {
        // Next button will be empty in Powermail 2.x
      //confirmation_next = Unverbindlich testen
    }
  }
}
  // plugin.caddy
';

    $installCase = $this->pObj->markerArray[ '###INSTALL_CASE###' ];
    switch( $installCase )
    {
      case( 'install_automaketemplate' ):
        $records[ $uid ][ 'config' ] = $records[ $uid ][ 'config' ] . '

  // Don\'t display the mini caddy
page.10.subparts.menue.10 >
';
        break;
      case( 'install_org' ):
        // Do nothing
        break;
      case( 'install_start' ):
        // Do nothing
        break;
      default:
        $prompt = __METHOD__ . ' #' . __LINE__ . ': Undefined value in switch: "' . $installCase . '"';
        die( $prompt );
    }

    return $records;
  }

  /**
   * pageOrgDocumentsCaddy( )
   *
   * @return	void
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrgDocumentsCaddy()
  {
    $records = array();
    $pageTitle = $this->pObj->pi_getLL( 'pageOrgDocumentsCaddy_title' );

    // 160720, dwildt, 3-
//    // Update the jss script
//    $records = $this->pageOrgDocumentsCaddy_contentJss();
//    $this->sqlUpdateContent( $records, $pageTitle );
    // Update the powermail plugin
    $records = $this->pageOrgDocumentsCaddy_pluginPowermail();
    $this->sqlUpdatePlugin( $records, $pageTitle );

    // Update the caddy plugin
    $records = $this->pageOrgDocumentsCaddy_pluginCaddy();
    $this->sqlUpdatePlugin( $records, $pageTitle );

    // Update the TypoScript
    $records = $this->pageOrgDocumentsCaddy_typoscript();
    $this->sqlUpdateTyposcript( $records, $pageTitle );
  }

  /**
   * pageOrgDocumentsCaddy_contentJss( )
   *
   * @return	array		$records : the plugin record
   * @access private
   * @version 3.0.4
   * @since   3.0.4
   */
  private function pageOrgDocumentsCaddy_contentJss()
  {
    $records = null;
    $uid = $this->pObj->arr_contentUids[ 'content_pageOrgDocumentsCaddy_header' ];

    // values
    $llHeader = $this->pObj->pi_getLL( 'content_pageOrgDocumentsCaddy_header' );
    // values

    $pmFieldsetUid = $this->pObj->powermailPageOrgDocumentsCaddy->getValue( 'record_pm_fSets_title_deliveryAddress' );
    switch( true )
    {
      case( $this->pObj->powermailVersionInt < 1000000 ):
        $prompt = 'ERROR: unexpected result<br />
          powermail version is below 1.0.0: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
        die( $prompt );
        break;
      case( $this->pObj->powermailVersionInt < 2000000 ):
        $pmFieldsetHtmlId = 'tx-powermail-pi1_fieldset_' . $pmFieldsetUid;
        break;
      case( $this->pObj->powermailVersionInt < 4000000 ):
        $pmFieldsetHtmlId = 'powermail_fieldset_' . $pmFieldsetUid;
        break;
      case( $this->pObj->powermailVersionInt >= 4000000 ):
      default:
        $prompt = 'ERROR: unexpected result<br />
          powermail version is higher than 3.x: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
        die( $prompt );
        break;
    }

    // 160720, dwildt, 2-
//    $jssScript = $this->pObj->pi_getLL( 'content_pageOrgDocumentsCaddy_bodytext' );
//    $jssScript = str_replace( '###POWERMAIL_FIELDSET_DELIVERYORDER_ADDRESS###', $pmFieldsetHtmlId, $jssScript );


    $records[ $uid ][ 'header' ] = $llHeader;
    // 160720, dwildt, 1-
//    $records[ $uid ][ 'bodytext' ] = $jssScript;
    $records[ $uid ][ 'hidden' ] = 1;

    return $records;
  }

  /**
   * pageOrgDocumentsCaddy_pluginCaddy( )
   *
   * @return	array		$records : the plugin record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrgDocumentsCaddy_pluginCaddy()
  {
    $records = null;
    $uid = $this->pObj->arr_pluginUids[ 'pluginCaddyPageOrgDocumentsCaddy_header' ];
    $pmX = $this->powermailVersionAppendix();

    // values
    $llHeader = $this->pObj->pi_getLL( 'pluginCaddyPageOrgDocumentsCaddy_header' );
    // values

    $records[ $uid ][ 'header' ] = $llHeader;
    $records[ $uid ][ 'pi_flexform' ] = null .
            '<?xml version="1.0" encoding="utf-8" standalone="yes" ?>
<T3FlexForms>
    <data>
        <sheet index="note">
            <language index="lDEF">
                <field index="note">
                    <value index="vDEF">'
            . $this->pObj->pi_getLL( 'pluginCaddyPageOrgDocumentsCaddy_note_' . $pmX ) .
            '</value>
                </field>
            </language>
        </sheet>
        <sheet index="origin">
            <language index="lDEF">
                <field index="order">
                    <value index="vDEF">3972</value>
                </field>
                <field index="invoice">
                    <value index="vDEF">83</value>
                </field>
                <field index="deliveryorder">
                    <value index="vDEF">216</value>
                </field>
                <field index="min">
                    <value index="vDEF">1</value>
                </field>
                <field index="max">
                    <value index="vDEF">100</value>
                </field>
            </language>
        </sheet>
        <sheet index="email">
            <language index="lDEF">
                <field index="customerEmail">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgDocumentsCaddy_title', 'record_pm_field_title_email' ) .
            '</value>
                </field>
                <field index="termsMode">
                    <value index="vDEF">all</value>
                </field>
                <field index="revocationMode">
                    <value index="vDEF">all</value>
                </field>
                <field index="invoiceMode">
                    <value index="vDEF">all</value>
                </field>
                <field index="deliveryorderMode">
                    <value index="vDEF">all</value>
                </field>
                <field index="orderconfirmationMode">
                    <value index="vDEF">all</value>
                </field>
            </language>
        </sheet>
        <sheet index="invoice">
            <language index="lDEF">
                <field index="company">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgDocumentsCaddy_title', 'record_pm_field_title_companyBilling' ) .
            '</value>
                </field>
                <field index="firstName">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgDocumentsCaddy_title', 'record_pm_field_title_firstnameBilling' ) .
            '</value>
                </field>
                <field index="lastName">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgDocumentsCaddy_title', 'record_pm_field_title_surnameBilling' ) .
            '</value>
                </field>
                <field index="address">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgDocumentsCaddy_title', 'record_pm_field_title_streetBilling' ) .
            '</value>
                </field>
                <field index="zip">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgDocumentsCaddy_title', 'record_pm_field_title_zipBilling' ) .
            '</value>
                </field>
                <field index="city">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgDocumentsCaddy_title', 'record_pm_field_title_locationBilling' ) .
            '</value>
                </field>
                <field index="country">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgDocumentsCaddy_title', 'record_pm_field_title_countryBilling' ) .
            '</value>
                </field>
            </language>
        </sheet>
        <sheet index="deliveryorder">
            <language index="lDEF">
                <field index="company">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgDocumentsCaddy_title', 'record_pm_field_title_companyDelivery' ) .
            '</value>
                </field>
                <field index="firstName">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgDocumentsCaddy_title', 'record_pm_field_title_firstnameDelivery' ) .
            '</value>
                </field>
                <field index="lastName">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgDocumentsCaddy_title', 'record_pm_field_title_surnameDelivery' ) .
            '</value>
                </field>
                <field index="address">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgDocumentsCaddy_title', 'record_pm_field_title_streetDelivery' ) .
            '</value>
                </field>
                <field index="zip">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgDocumentsCaddy_title', 'record_pm_field_title_zipDelivery' ) .
            '</value>
                </field>
                <field index="city">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgDocumentsCaddy_title', 'record_pm_field_title_locationDelivery' ) .
            '</value>
                </field>
                <field index="country">
                    <value index="vDEF">'
            . $this->zz_getPowermailUid( 'pageOrgDocumentsCaddy_title', 'record_pm_field_title_countryDelivery' ) .
            '</value>
                </field>
            </language>
        </sheet>
        <sheet index="paths">
            <language index="lDEF">
                <field index="terms">
                    <value index="vDEF">typo3conf/ext/org/Resources/Public/Files/typo3-organiser_for_caddy.pdf</value>
                </field>
                <field index="revocation">
                    <value index="vDEF">typo3conf/ext/org/Resources/Public/Files/typo3-organiser_for_caddy.pdf</value>
                </field>
                <field index="invoice">
                    <value index="vDEF">typo3conf/ext/org/Resources/Public/Files/typo3-organiser_for_caddy.pdf</value>
                </field>
                <field index="deliveryorder">
                    <value index="vDEF">typo3conf/ext/org/Resources/Public/Files/typo3-organiser_for_caddy.pdf</value>
                </field>
                <field index="orderconfirmation">
                    <value index="vDEF">typo3conf/ext/org/Resources/Public/Files/typo3-organiser_for_caddy.pdf</value>
                </field>
            </language>
        </sheet>
    </data>
</T3FlexForms>
';

    return $records;
  }

  /**
   * pageOrgDocumentsCaddy_pluginPowermail( )
   *
   * @return	array		$records : the plugin record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrgDocumentsCaddy_pluginPowermail()
  {
    $records = null;

    switch( true )
    {
      case( $this->pObj->powermailVersionInt < 1000000 ):
        $prompt = 'ERROR: unexpected result<br />
          powermail version is below 1.0.0: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
        die( $prompt );
        break;
      case( $this->pObj->powermailVersionInt < 2000000 ):
        $records = $this->pageOrgDocumentsCaddy_pluginPowermail1x();
        break;
      case( $this->pObj->powermailVersionInt < 4000000 ):
        $records = $this->pageOrgDocumentsCaddy_pluginPowermail2x();
        break;
      case( $this->pObj->powermailVersionInt >= 4000000 ):
      default:
        $prompt = 'ERROR: unexpected result<br />
          powermail version is higher than 3.x: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
        die( $prompt );
        break;
    }

    return $records;
  }

  /**
   * pageOrgDocumentsCaddy_pluginPowermail1x( )
   *
   * @return	array		$records : the plugin record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrgDocumentsCaddy_pluginPowermail1x()
  {
    $records = null;
    $uid = $this->pObj->arr_pluginUids[ 'pluginPowermailPageOrgDocumentsCaddy_header' ];

    // values
    $llHeader = $this->pObj->pi_getLL( 'pluginPowermailPageOrgDocumentsCaddy_header' );
    $uidEmail = $this->pObj->powermailPageOrgDocumentsCaddy->getValue( 'record_pm_field_title_email' );
    $customerEmail = 'uid' . $uidEmail;
    $uidFirstname = $this->pObj->powermailPageOrgDocumentsCaddy->getValue( 'record_pm_field_title_firstnameBilling' );
    $uidSurname = $this->pObj->powermailPageOrgDocumentsCaddy->getValue( 'record_pm_field_title_surnameBilling' );
    $customerName = 'uid' . $uidFirstname . ',uid' . $uidSurname;
    // values

    $records[ $uid ][ 'header' ] = $llHeader;
    $records[ $uid ][ 'tx_powermail_sender' ] = $customerEmail;
    $records[ $uid ][ 'tx_powermail_sendername' ] = $customerName;

    return $records;
  }

  /**
   * pageOrgDocumentsCaddy_pluginPowermail2x( )
   *
   * @return	array		$records : the plugin record
   * @access private
	 * @internal #i0071: settings.flexform.main.moresteps = 1
   * @version 8.0.15
   * @since   3.0.0
   */
  private function pageOrgDocumentsCaddy_pluginPowermail2x()
  {
    $records = null;
    $uid = $this->pObj->arr_pluginUids[ 'pluginPowermailPageOrgDocumentsCaddy_header' ];

    $llHeader = $this->pObj->pi_getLL( 'pluginPowermailPageOrgDocumentsCaddy_header' );
    $uidForm = $this->pObj->powermailPageOrgDocumentsCaddy->getValue( 'record_pm_form_title_pageOrgDocumentsCaddy' );
    $receiverSubject = $this->pObj->pi_getLL( 'pluginPowermailPageOrgDocumentsCaddy_subject_r2x' );
    $receiverBody = htmlspecialchars( $this->pObj->pi_getLL( 'pluginPowermailPageOrgDocumentsCaddy_body_r2x' ) );
    // #i0016, 140926, dwildt, 3-
//    list( $name, $domain) = explode( '@', $this->pObj->markerArray['###MAIL_DEFAULT_RECIPIENT###'] );
//    unset( $name );
//    $senderEmail      = 'noreply@' . $domain;
    // #i0016, 140926, dwildt, 3-
    $providerEmail = $this->pObj->markerArray[ '###MAIL_DEFAULT_RECIPIENT###' ];
    list( $name, $domain) = explode( '@', $providerEmail );
    unset( $name );
    $noreplyEmail = 'noreply@' . $domain;
    $senderSubject = $this->pObj->pi_getLL( 'pluginPowermailPageOrgDocumentsCaddy_subject_s2x' );
    $senderBody = htmlspecialchars( $this->pObj->pi_getLL( 'pluginPowermailPageOrgDocumentsCaddy_body_s2x' ) );
    $thxBody = htmlspecialchars( $this->pObj->pi_getLL( 'pluginPowermailPageOrgDocumentsCaddy_thanks2x' ) );

    $records[ $uid ][ 'header' ] = $llHeader;
    $records[ $uid ][ 'pi_flexform' ] = null .
            '<?xml version="1.0" encoding="utf-8" standalone="yes" ?>
<T3FlexForms>
    <data>
        <sheet index="main">
            <language index="lDEF">
                <field index="settings.flexform.main.form">
                    <value index="vDEF">' . $uidForm . '</value>
                </field>
                <field index="settings.flexform.main.confirmation">
                    <value index="vDEF">1</value>
                </field>
                <field index="settings.flexform.main.moresteps">
                    <value index="vDEF">1</value>
                </field>
            </language>
        </sheet>
        <sheet index="receiver">
            <language index="lDEF">
                <field index="settings.flexform.receiver.name">
                    <value index="vDEF">{billingaddressfirstname} {billingaddresslastname}</value>
                </field>
                <field index="settings.flexform.receiver.email">
                    <value index="vDEF">' . $providerEmail . '</value>
                </field>
                <field index="settings.flexform.receiver.subject">
                    <value index="vDEF">' . $receiverSubject . '</value>
                </field>
                <field index="settings.flexform.receiver.body">
                    <value index="vDEF">' . $receiverBody . '</value>
                    <value index="_TRANSFORM_vDEF.vDEFbase">' . $receiverBody . '</value>
                </field>
            </language>
        </sheet>
        <sheet index="sender">
            <language index="lDEF">
                <field index="settings.flexform.sender.name">
                    <value index="vDEF">Organiser</value>
                </field>
                <field index="settings.flexform.sender.email">
                    <value index="vDEF">' . $noreplyEmail . '</value>
                </field>
                <field index="settings.flexform.sender.subject">
                    <value index="vDEF">' . $senderSubject . '</value>
                </field>
                <field index="settings.flexform.sender.body">
                    <value index="vDEF">' . $senderBody . '</value>
                    <value index="_TRANSFORM_vDEF.vDEFbase">' . $senderBody . '</value>
                </field>
            </language>
        </sheet>
        <sheet index="thx">
            <language index="lDEF">
                <field index="settings.flexform.thx.body">
                    <value index="vDEF">' . $thxBody . '</value>
                    <value index="_TRANSFORM_vDEF.vDEFbase">' . $thxBody . '</value>
                </field>
                <field index="settings.flexform.thx.redirect">
                    <value index="vDEF"></value>
                </field>
            </language>
        </sheet>
    </data>
</T3FlexForms>';

    return $records;
  }

  /**
   * pageOrgDocumentsCaddy_typoscript( )
   *
   * @return	array		$records    : the TypoScript record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrgDocumentsCaddy_typoscript()
  {
    $records = null;

    $pmX = $this->powermailVersionAppendix();
    switch( true )
    {
      case( $pmX == '1x' ):
        $records = $this->pageOrgDocumentsCaddy_typoscript1x();
        break;
      case( $pmX == '2x' ):
        $records = $this->pageOrgDocumentsCaddy_typoscript2x();
        break;
      default:
        $prompt = 'ERROR: unexpected result<br />
          powermail version is neither 1x nor 2x. Internal: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
        die( $prompt );
        break;
    }

    unset( $pmX );

    return $records;
  }

  /**
   * pageOrgDocumentsCaddy_typoscript1x( )
   *
   * @return	array		$records    : the TypoScript record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrgDocumentsCaddy_typoscript1x()
  {
    $records = null;

    $title = 'pageOrgDocumentsCaddy_title';
    $uid = $this->pObj->arr_tsUids[ $title ];

    $strUid = sprintf( '%03d', $uid );
    $llTitle = strtolower( $this->pObj->pi_getLL( $title ) );
    $llTitle = str_replace( ' ', null, $llTitle );
    $llTitle = '+page_' . $llTitle . '_' . $strUid;

    list( $noreply, $domain ) = explode( '@', $this->pObj->markerArray[ '###MAIL_DEFAULT_RECIPIENT###' ] );
    $noreply = 'noreply@' . $domain;


    $records[ $uid ][ 'title' ] = $llTitle;
    $records[ $uid ][ 'constants' ] = '
  /////////////////////////////////////////
  //
  // INDEX
  //
  // plugin.caddy
  // plugin.powermail



//  Not needed: Is included at the page documents
//
//  /////////////////////////////////////////
//  //
//  // plugin.caddy
//
//plugin.caddy {
//  pages {
//    caddy       = ' . $this->pObj->arr_pageUids[ 'pageOrgDocumentsCaddy_title' ] . '
//    caddymini   = ' . $this->pObj->arr_pageUids[ 'pageOrgDocumentsCaddyCaddymini_title' ] . '
//    revocation  = ' . $this->pObj->arr_pageUids[ 'pageOrgDocumentsRevocation_title' ] . '
//    shop        = ' . $this->pObj->arr_pageUids[ 'pageOrgDocuments_title' ] . '
//    terms       = ' . $this->pObj->arr_pageUids[ 'pageOrgDocumentsTerms_title' ] . '
//  }
//}



  /////////////////////////////////////////
  //
  // plugin.powermail

plugin.powermail {
  js {
    toHeader = 1
  }
}
  // plugin.powermail

';

    $records[ $uid ][ 'config' ] = '
plugin.tx_powermail_pi1 {
  email {
    sender_mail {
      sender {
        name {
          value = Organiser
        }
        email {
          value = ' . $noreply . '
        }
      }
    }
  }
  _LOCAL_LANG {
    default {
      locallangmarker_confirmation_submit = Test Organiser without commitment!
    }
    de {
      locallangmarker_confirmation_submit = Organiser unverbindlich testen!
    }
  }
}';

    $installCase = $this->pObj->markerArray[ '###INSTALL_CASE###' ];
    switch( $installCase )
    {
      case( 'install_automaketemplate' ):
        $records[ $uid ][ 'config' ] = $records[ $uid ][ 'config' ] . '

  // Don\'t display the mini caddy
page.10.subparts.menue.10 >
';
        break;
      case( 'install_org' ):
        // Do nothing
        break;
      case( 'install_start' ):
        // Do nothing
        break;
      default:
        $prompt = __METHOD__ . ' #' . __LINE__ . ': Undefined value in switch: "' . $installCase . '"';
        die( $prompt );
    }

    return $records;
  }

  /**
   * pageOrgDocumentsCaddy_typoscript2x( )
   *
   * @return	array		$records    : the TypoScript record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrgDocumentsCaddy_typoscript2x()
  {
    $records = null;

    $title = 'pageOrgDocumentsCaddy_title';
    $uid = $this->pObj->arr_tsUids[ $title ];

    $strUid = sprintf( '%03d', $uid );
    $llTitle = strtolower( $this->pObj->pi_getLL( $title ) );
    $llTitle = str_replace( ' ', null, $llTitle );
    $llTitle = '+page_' . $llTitle . '_' . $strUid;

    $records[ $uid ][ 'title' ] = $llTitle;
    $records[ $uid ][ 'constants' ] = '
  /////////////////////////////////////////
  //
  // INDEX
  //
  // plugin.caddy
  // plugin.tx_powermail



//  Not needed: Is included at the page documents
//
//  /////////////////////////////////////////
//  //
//  // plugin.caddy
//
//plugin.caddy {
//  pages {
//    caddy       = ' . $this->pObj->arr_pageUids[ 'pageOrgDocumentsCaddy_title' ] . '
//    caddymini   = ' . $this->pObj->arr_pageUids[ 'pageOrgDocumentsCaddyCaddymini_title' ] . '
//    revocation  = ' . $this->pObj->arr_pageUids[ 'pageOrgDocumentsRevocation_title' ] . '
//    shop        = ' . $this->pObj->arr_pageUids[ 'pageOrgDocuments_title' ] . '
//    terms       = ' . $this->pObj->arr_pageUids[ 'pageOrgDocumentsTerms_title' ] . '
//  }
//}


  /////////////////////////////////////////
  //
  // plugin.caddy

plugin.caddy {
  deliveryaddress {
    includescript = 1
    powermail {
      debug = 0
    }
  }
  // 170408, dwildt, -
//  powermail {
//    tabs {
//      debug = 0
//      id {              
//        tab01 = tab_' . $this->pObj->powermailPageOrgCaddy->getValue( 'record_pm_fSets_title_billingAddress' ) . '
//        tab02 = tab_' . $this->pObj->powermailPageOrgCaddy->getValue( 'record_pm_fSets_title_deliveryAddress' ) . '
//        tab03 = tab_' . $this->pObj->powermailPageOrgCaddy->getValue( 'record_pm_fSets_title_contactData' ) . '
//        tab04 = tab_' . $this->pObj->powermailPageOrgCaddy->getValue( 'record_pm_fSets_title_order' ) . '
//      }
//      includescript = 1
//    }
//  }
}
  // plugin.caddy




  /////////////////////////////////////////
  //
  // plugin.tx_powermail

plugin.tx_powermail {
  settings {
    javascript {
        // We take jQuery from tx_browser_pi1 or from T3jQuery (recommended)
      powermailJQuery =
      powermailJQueryUi =
    }
  }
}
  // plugin.tx_powermail

';

    $records[ $uid ][ 'config' ] = '
plugin.tx_powermail {
  _LOCAL_LANG {
    default {
        // Next button will be empty in Powermail 2.x
      //confirmation_next = Order without commitment
    }
    de {
        // Next button will be empty in Powermail 2.x
      //confirmation_next = Unverbindlich testen
    }
  }
}
';

    $installCase = $this->pObj->markerArray[ '###INSTALL_CASE###' ];
    switch( $installCase )
    {
      case( 'install_automaketemplate' ):
        $records[ $uid ][ 'config' ] = $records[ $uid ][ 'config' ] . '

  // Don\'t display the mini caddy
page.10.subparts.menue.10 >
';
        break;
      case( 'install_org' ):
        // Do nothing
        break;
      case( 'install_start' ):
        // Do nothing
        break;
      default:
        $prompt = __METHOD__ . ' #' . __LINE__ . ': Undefined value in switch: "' . $installCase . '"';
        die( $prompt );
    }

    return $records;
  }

  /**
   * pageOrgLibraryHeaderLogo( )
   *
   * @return	array		$records    : the TypoScript record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrgLibraryHeaderLogo()
  {
    $records = array();
    $pageUid = $this->pObj->arr_pageUids[ 'pageOrgLibraryHeaderLogo_title' ];
    $pageTitle = $this->pObj->arr_pageTitles[ $pageUid ];

    // Update page properties
    $records = $this->pageOrgLibraryHeaderLogo_content();
    $this->sqlUpdateContent( $records, $pageTitle );
  }

  /**
   * pageOrgLibraryHeaderLogo_content( )
   *
   * @return	array		$records    : the TypoScript record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrgLibraryHeaderLogo_content()
  {
    $records = null;

    $llLabel = 'content_pageOrgLibraryHeaderLogo_header';
    $llTitle = $this->pObj->pi_getLL( $llLabel );
    $uid = $this->pObj->arr_contentUids[ $llLabel ];

    $image_link = $this->pObj->pi_getLL( 'content_pageOrgLibraryHeaderLogo_image_link' );
    $image_link = $this->zz_replacePageUids( $image_link );

    $records[ $uid ][ 'header' ] = $llTitle;
    $records[ $uid ][ 'image_link' ] = $image_link;
    // #i0002, 13-07-30, dwildt, 1+
    $records[ $uid ][ 'image_zoom' ] = 1;


    return $records;
  }

  /**
   * pageOrgData( )
   *
   * @return	void
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrgData()
  {
    $records = array();
    $pageUid = $this->pObj->arr_pageUids[ 'pageOrgData_title' ];
    $pageTitle = $this->pObj->arr_pageTitles[ $pageUid ];

    // Update page properties
    $records = $this->pageOrgData_properties();
    $this->sqlUpdatePages( $records, $pageTitle );
  }

  /**
   * pageOrgData_properties( )
   *
   * @return	array		$records    : the TypoScript record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function pageOrgData_properties()
  {
    $records = null;

    $uid = $this->pObj->arr_pageUids[ 'pageOrgData_title' ];
    $groupUid = $this->pObj->markerArray[ '###GROUP_UID###' ];
    $groupTitle = $this->pObj->markerArray[ '###GROUP_TITLE###' ];

    $dateHumanReadable = date( 'Y-m-d G:i:s' );

    $records[ $uid ][ 'TSconfig' ] = '

// Created by ORGANISER INSTALLER at ' . $dateHumanReadable . ' -- BEGIN



  ///////////////////////////
  //
  // INDEX

  // TCEFORM
  //    organiser tables
  // TCEMAIN
  //    clearCacheCmd
  //    permissions
  // MOD
  //    web_layout



  // PID
  // [' . $uid . '] organiser
  //    [%pageOrgDataCal_title%] calendar
  //    [%pageOrgDataDownloads_title%] downloads
  //    [%pageOrgDataEvents_title%] events
  //    [%pageOrgDataHeadquarters_title%] headquarters
  //    [%pageOrgDataJobs_title%] jobs
  //    [%pageOrgDataLocations_title%] locations
  //    [%pageOrgDataNews_title%] news
  //    [%pageOrgDataService_title%] services
  //    [%pageOrgDataStaff_title%] staff

  // organiser tables
TCEFORM {
  tx_org_cal_all_tables {
    tx_org_cal {
      PAGE_TSCONFIG_IDLIST  = ' . $uid . ',%pageOrgDataCal_title%
      PAGE_TSCONFIG_ID      = %pageOrgDataCal_title%
    }
    tx_org_calcal      < .tx_org_cal
    tx_org_calcat      < .tx_org_cal
    tx_org_calentrance < .tx_org_cal
    tx_org_caltype     < .tx_org_cal
    tx_org_downloads {
      PAGE_TSCONFIG_IDLIST  = ' . $uid . ',%pageOrgDataDownloads_title%
      PAGE_TSCONFIG_ID      = %pageOrgDataDownloads_title%
    }
    tx_org_downloadscat   < .tx_org_downloads
    tx_org_downloadsmedia < .tx_org_downloads
    tx_org_event {
      PAGE_TSCONFIG_IDLIST  = ' . $uid . ',%pageOrgDataEvents_title%
      PAGE_TSCONFIG_ID      = %pageOrgDataEvents_title%
    }
    tx_org_eventcat < .tx_org_event
    tx_org_headquarters {
      PAGE_TSCONFIG_IDLIST  = ' . $uid . ',%pageOrgDataHeadquarters_title%
      PAGE_TSCONFIG_ID      = %pageOrgDataHeadquarters_title%
    }
    tx_org_headquarterscat < .tx_org_headquarters
    tx_org_job {
      PAGE_TSCONFIG_IDLIST  = ' . $uid . ',%pageOrgDataJobs_title%
      PAGE_TSCONFIG_ID      = %pageOrgDataJobs_title%
    }
    tx_org_jobcat < .tx_org_job
    tx_org_jobsector < .tx_org_job
    tx_org_jobworkinghours < .tx_org_job
    tx_org_location {
      PAGE_TSCONFIG_IDLIST  = ' . $uid . ',%pageOrgDataLocations_title%
      PAGE_TSCONFIG_ID      = %pageOrgDataLocations_title%
    }
    tx_org_locationcat < .tx_org_location
    tx_org_news {
      PAGE_TSCONFIG_IDLIST  = ' . $uid . ',%pageOrgDataNews_title%
      PAGE_TSCONFIG_ID      = %pageOrgDataNews_title%
    }
    tx_org_newscat < .tx_org_news
    tx_org_newsgroup < .tx_org_news
    tx_org_service {
      PAGE_TSCONFIG_IDLIST  = ' . $uid . ',%pageOrgDataService_title%
      PAGE_TSCONFIG_ID      = %pageOrgDataService_title%
    }
    tx_org_servicecat < .tx_org_service
    tx_org_servicesector < .tx_org_service
    tx_org_servicetargetgroup < .tx_org_service
    tx_org_staff {
      PAGE_TSCONFIG_IDLIST  = ' . $uid . ',%pageOrgDataStaff_title%
      PAGE_TSCONFIG_ID      = %pageOrgDataStaff_title%
    }
    tx_org_staffcat < .tx_org_staff
  }
  tx_org_cal                < .tx_org_cal_all_tables
  tx_org_calcal							< .tx_org_cal_all_tables
  tx_org_calcat             < .tx_org_cal_all_tables
  tx_org_calentrance        < .tx_org_cal_all_tables
  tx_org_caltype            < .tx_org_cal_all_tables
  tx_org_downloads          < .tx_org_cal_all_tables
  tx_org_downloadscat       < .tx_org_cal_all_tables
  tx_org_downloadsmedia     < .tx_org_cal_all_tables
  tx_org_event              < .tx_org_cal_all_tables
  tx_org_eventcat           < .tx_org_cal_all_tables
  tx_org_headquarters       < .tx_org_cal_all_tables
  tx_org_headquarterscat    < .tx_org_cal_all_tables
  tx_org_job                < .tx_org_cal_all_tables
  tx_org_jobcat             < .tx_org_cal_all_tables
  tx_org_jobsector          < .tx_org_cal_all_tables
  tx_org_jobworkinghours    < .tx_org_cal_all_tables
  tx_org_location           < .tx_org_cal_all_tables
  tx_org_locationcat        < .tx_org_cal_all_tables
  tx_org_news               < .tx_org_cal_all_tables
  tx_org_newscat            < .tx_org_cal_all_tables
  tx_org_newsgroup          < .tx_org_cal_all_tables
  tx_org_service            < .tx_org_cal_all_tables
  tx_org_servicecat         < .tx_org_cal_all_tables
  tx_org_servicesector      < .tx_org_cal_all_tables
  tx_org_servicetargetgroup < .tx_org_cal_all_tables
  tx_org_staff              < .tx_org_cal_all_tables
  tx_org_staffgroup         < .tx_org_cal_all_tables
}
  // organiser tables
  // TCEFORM



  ////////////////////////////////////////////////////////////////////////
  //
  // TCEMAIN

TCEMAIN {
  clearCacheCmd = pages
  permissions {
    // ' . $groupUid . ': ' . $groupTitle . '
    groupid = ' . $groupUid . '
    group   = show,edit,delete,new,editcontent
  }
}
  // TCEMAIN



  ///////////////////////////
  //
  // MOD

mod {
  web_list {
      // Deny all tables!
    allowedNewTables = xxx
  }
}
  // MOD


// Created by ORGANISER INSTALLER at ' . $dateHumanReadable . ' -- END

';
    $records[ $uid ][ 'TSconfig' ] = $this->zz_replacePageUids( $records[ $uid ][ 'TSconfig' ] );

    return $records;
  }

  /*   * *********************************************
   *
   * Sql
   *
   * ******************************************** */

  /**
   * sqlUpdateContent( )
   *
   * @param	array		$records  : tt_content records for pages
   * @param	string		$pageTitle  : title of the page
   * @return	void
   * @access private
   * @version 3.0.4
   * @since   3.0.4
   */
  private function sqlUpdateContent( $records, $pageTitle )
  {
    $table = 'tt_content';

    foreach( $records as $uid => $record )
    {
      $where = 'uid = ' . $uid;
      $fields = array_keys( $record );
      $csvFields = implode( ', ', $fields );
      $csvFields = str_replace( 'header, ', null, $csvFields );

      //var_dump( __METHOD__, __LINE__, $GLOBALS['TYPO3_DB']->UPDATEquery( $table, $where, $record ) );
      $GLOBALS[ 'TYPO3_DB' ]->exec_UPDATEquery( $table, $where, $record );

      $error = $GLOBALS[ 'TYPO3_DB' ]->sql_error();

      if( $error )
      {
        $query = $GLOBALS[ 'TYPO3_DB' ]->UPDATEquery( $table, $where, $record );
        $prompt = 'SQL-ERROR<br />' . PHP_EOL .
                'query: ' . $query . '.<br />' . PHP_EOL .
                'error: ' . $error . '.<br />' . PHP_EOL .
                'Sorry for the trouble.<br />' . PHP_EOL .
                'TYPO3-Organiser Installer<br />' . PHP_EOL .
                __METHOD__ . ' (' . __LINE__ . ')';
        die( $prompt );
      }

      $this->pObj->markerArray[ '###FIELD###' ] = $csvFields;
      $this->pObj->markerArray[ '###TITLE###' ] = '"' . $record[ 'header' ] . '"';
      $this->pObj->markerArray[ '###TITLE_PID###' ] = '"' . $pageTitle . '" (uid ' . $uid . ')';
      $prompt = '
        <p>
          ' . $this->pObj->arr_icons[ 'ok' ] . ' ' . $this->pObj->pi_getLL( 'consolidate_prompt_content' ) . '
        </p>';
      $prompt = $this->pObj->cObj->substituteMarkerArray( $prompt, $this->pObj->markerArray );
      $this->pObj->arrReport[] = $prompt;
    }
  }

  /**
   * sqlUpdatePlugin( )
   *
   * @param	array		$records  : tt_content records for pages
   * @param	string		$pageTitle  : title of the page
   * @return	void
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function sqlUpdatePlugin( $records, $pageTitle )
  {
    $this->sqlUpdateContent( $records, $pageTitle );
  }

  /**
   * powermailVersionAppendix( )
   *
   * @return	array		$records : the plugin record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function powermailVersionAppendix()
  {
    if( $this->powermailVersionAppendix !== null )
    {
      return $this->powermailVersionAppendix;
    }

    switch( true )
    {
      case( $this->pObj->powermailVersionInt < 1000000 ):
        $prompt = 'ERROR: unexpected result<br />
          powermail version is below 1.0.0: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
        die( $prompt );
        break;
      case( $this->pObj->powermailVersionInt < 2000000 ):
        $this->powermailVersionAppendix = '1x';
        break;
      case( $this->pObj->powermailVersionInt < 4000000 ):
        $this->powermailVersionAppendix = '2x';
        break;
      case( $this->pObj->powermailVersionInt >= 4000000 ):
      default:
        $prompt = 'ERROR: unexpected result<br />
          powermail version is higher than 3.x: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
        die( $prompt );
        break;
    }

    return $this->powermailVersionAppendix;
  }

  /**
   * sqlUpdatePages( )
   *
   * @param	array		$records  : TypoScript records for pages
   * @param	string		$pageTitle  : title of the page
   * @return	void
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function sqlUpdatePages( $records, $pageTitle )
  {
    $table = 'pages';

    foreach( $records as $uid => $record )
    {
      $where = 'uid = ' . $uid;
      $fields = array_keys( $record );
      $csvFields = implode( ', ', $fields );

//      var_dump( __METHOD__, __LINE__, $GLOBALS['TYPO3_DB']->UPDATEquery( $table, $where, $record ) );
      $GLOBALS[ 'TYPO3_DB' ]->exec_UPDATEquery( $table, $where, $record );

      $error = $GLOBALS[ 'TYPO3_DB' ]->sql_error();

      if( $error )
      {
        $query = $GLOBALS[ 'TYPO3_DB' ]->UPDATEquery( $table, $where, $record );
        $prompt = 'SQL-ERROR<br />' . PHP_EOL .
                'query: ' . $query . '.<br />' . PHP_EOL .
                'error: ' . $error . '.<br />' . PHP_EOL .
                'Sorry for the trouble.<br />' . PHP_EOL .
                'TYPO3-Organiser Installer<br />' . PHP_EOL .
                __METHOD__ . ' (' . __LINE__ . ')';
        die( $prompt );
      }

      $this->pObj->markerArray[ '###FIELD###' ] = $csvFields;
      $this->pObj->markerArray[ '###TITLE_PID###' ] = '"' . $pageTitle . '" (uid ' . $uid . ')';
      $prompt = '
        <p>
          ' . $this->pObj->arr_icons[ 'ok' ] . ' ' . $this->pObj->pi_getLL( 'consolidate_prompt_page' ) . '
        </p>';
      $prompt = $this->pObj->cObj->substituteMarkerArray( $prompt, $this->pObj->markerArray );
      $this->pObj->arrReport[] = $prompt;
    }
  }

  /**
   * sqlUpdateTyposcript( )
   *
   * @param	array		$records  : TypoScript records for pages
   * @param	string		$pageTitle  : title of the page
   * @return	void
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function sqlUpdateTyposcript( $records, $pageTitle )
  {
    $table = 'sys_template';

    foreach( $records as $uid => $record )
    {
      $where = 'uid = ' . $uid;
      $fields = array_keys( $record );
      $csvFields = implode( ', ', $fields );
      $csvFields = str_replace( 'title, ', null, $csvFields );

      //var_dump( __METHOD__, __LINE__, $GLOBALS['TYPO3_DB']->UPDATEquery( $table, $where, $record ) );
      $GLOBALS[ 'TYPO3_DB' ]->exec_UPDATEquery( $table, $where, $record );

      $error = $GLOBALS[ 'TYPO3_DB' ]->sql_error();

      if( $error )
      {
        $query = $GLOBALS[ 'TYPO3_DB' ]->UPDATEquery( $table, $where, $record );
        $prompt = 'SQL-ERROR<br />' . PHP_EOL .
                'query: ' . $query . '.<br />' . PHP_EOL .
                'error: ' . $error . '.<br />' . PHP_EOL .
                'Sorry for the trouble.<br />' . PHP_EOL .
                'TYPO3-Organiser Installer<br />' . PHP_EOL .
                __METHOD__ . ' (' . __LINE__ . ')';
        die( $prompt );
      }
      $this->pObj->markerArray[ '###FIELD###' ] = $csvFields;
      $this->pObj->markerArray[ '###TITLE###' ] = '"' . $record[ 'title' ] . '"';
      $this->pObj->markerArray[ '###TITLE_PID###' ] = '"' . $pageTitle . '" (uid ' . $uid . ')';
      $prompt = '
        <p>
          ' . $this->pObj->arr_icons[ 'ok' ] . ' ' . $this->pObj->pi_getLL( 'consolidate_prompt_content' ) . '
        </p>';
      $prompt = $this->pObj->cObj->substituteMarkerArray( $prompt, $this->pObj->markerArray );
      $this->pObj->arrReport[] = $prompt;
    }
  }

  /**
   * sqlUpdateTyposcriptOtherHide( )
   *
   * @return	void
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function sqlUpdateTyposcriptOtherHide()
  {
    $pageTitle = $GLOBALS[ 'TSFE' ]->page[ 'title' ];

    $table = 'sys_template';

    $record = array( 'hidden' => 1 );

    $uid = $this->pObj->arr_tsUids[ $this->pObj->str_tsRoot ];
    $pid = $GLOBALS[ 'TSFE' ]->id;
    $where = 'pid = ' . $pid . ' AND uid NOT LIKE ' . $uid;

    //var_dump( __METHOD__, __LINE__, $GLOBALS['TYPO3_DB']->UPDATEquery( $table, $where, $record ) );
    $GLOBALS[ 'TYPO3_DB' ]->exec_UPDATEquery( $table, $where, $record );

    $error = $GLOBALS[ 'TYPO3_DB' ]->sql_error();

    if( $error )
    {
      $query = $GLOBALS[ 'TYPO3_DB' ]->UPDATEquery( $table, $where, $record );
      $prompt = 'SQL-ERROR<br />' . PHP_EOL .
              'query: ' . $query . '.<br />' . PHP_EOL .
              'error: ' . $error . '.<br />' . PHP_EOL .
              'Sorry for the trouble.<br />' . PHP_EOL .
              'TYPO3-Organiser Installer<br />' . PHP_EOL .
              __METHOD__ . ' (' . __LINE__ . ')';
      die( $prompt );
    }

    $this->pObj->markerArray[ '###TITLE_PID###' ] = '"' . $pageTitle . '" (uid ' . $uid . ')';
    $prompt = '
      <p>
        ' . $this->pObj->arr_icons[ 'ok' ] . ' ' . $this->pObj->pi_getLL( 'consolidate_prompt_template' ) . '
      </p>';
    $prompt = $this->pObj->cObj->substituteMarkerArray( $prompt, $this->pObj->markerArray );
    $this->pObj->arrReport[] = $prompt;
  }

  /*   * *********************************************
   *
   * ZZ
   *
   * ******************************************** */

  /**
   * zz_getPowermailUid( )
   *
   * @param	string		$label        : label for the powermail field
   * @return	string		$powermailUid : uid of the powermail field record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function zz_getPowermailUid( $page, $label )
  {
    $powermailUid = null;

    switch( true )
    {
      case( $this->pObj->powermailVersionInt < 1000000 ):
        $prompt = 'ERROR: unexpected result<br />
          powermail version is below 1.0.0: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
        die( $prompt );
        break;
      case( $this->pObj->powermailVersionInt < 2000000 ):
        $powermailUid = $this->zz_getPowermailUid1x( $page, $label );
        break;
      case( $this->pObj->powermailVersionInt < 4000000 ):
        $powermailUid = $this->zz_getPowermailUid2x( $page, $label );
        break;
      case( $this->pObj->powermailVersionInt >= 4000000 ):
      default:
        $prompt = 'ERROR: unexpected result<br />
          powermail version is higher than 3.x: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
        die( $prompt );
        break;
    }

    return $powermailUid;
  }

  /**
   * zz_getPowermailUid1x( )
   *
   * @param	string		$label        : label for the powermail field
   * @return	string		$powermailUid : uid of the powermail field record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function zz_getPowermailUid1x( $page, $label )
  {
    switch( $page )
    {
      case( 'pageOrgCalCaddy_title' ):
        $powermailUid = $this->pObj->powermailPageOrgCaddy->getValue( $label );
        break;
      case( 'pageOrgDocumentsCaddy_title' ):
        $powermailUid = $this->pObj->powermailPageOrgDocumentsCaddy->getValue( $label );
        break;
      default:
        $prompt = __METHOD__ . ' #' . __LINE__ . ': undefined value in switch!';
        die( $prompt );
        break;
    }

    return $powermailUid;
  }

  /**
   * zz_getPowermailUid2x( )
   *
   * @param	string		$label        : label for the powermail field
   * @return	string		$powermailUid : uid of the powermail field record
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function zz_getPowermailUid2x( $page, $label )
  {
    switch( $page )
    {
      case( 'pageOrgCalCaddy_title' ):
//        $powermailUid = 'tx_powermail_domain_model_fields_' . $this->pObj->powermailPageOrgCaddy->getValue( $label );
        $powermailUid = $this->pObj->powermailPageOrgCaddy->getValue( $label );
        break;
      case( 'pageOrgDocumentsCaddy_title' ):
//        $powermailUid = 'tx_powermail_domain_model_fields_' . $this->pObj->powermailPageOrgDocumentsCaddy->getValue( $label );
        $powermailUid = $this->pObj->powermailPageOrgDocumentsCaddy->getValue( $label );
        break;
      default:
        $prompt = __METHOD__ . ' #' . __LINE__ . ': undefined value in switch!';
        die( $prompt );
        break;
    }

    return $powermailUid;
  }

  /**
   * zz_replacePageUids( )
   *
   * @param       string          $content
   * @return	string		$content
   * @access private
   * @version 3.0.0
   * @since   3.0.0
   */
  private function zz_replacePageUids( $content )
  {
    $needle = array();
    $replace = array();

    foreach( ( array ) $this->pObj->arr_pageUids as $page => $uid )
    {
      $needle[] = '%' . $page . '%';
      $replace[] = $uid;
    }

    $content = str_replace( $needle, $replace, $content );


    return $content;
  }

}

if( defined( 'TYPO3_MODE' ) && $TYPO3_CONF_VARS[ TYPO3_MODE ][ 'XCLASS' ][ 'ext/org_installer/pi1/class.tx_orginstaller_pi1_consolidate.php' ] )
{
  include_once($TYPO3_CONF_VARS[ TYPO3_MODE ][ 'XCLASS' ][ 'ext/org_installer/pi1/class.tx_orginstaller_pi1_consolidate.php' ]);
}