<?php

use TYPO3\CMS\Core\Utility\PathUtility;
use TYPO3\CMS\Core\Resource\ResourceFactory;

/* * *************************************************************
 *  Copyright notice
 *
 *  (c) 2016-2017 - Dirk Wildt <http://wildt.at.die-netzmacher.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 * ************************************************************* */

/**
 * Plugin 'Organiser Installer' for the 'org_installer' extension.
 *
 * @author    Dirk Wildt <http://wildt.at.die-netzmacher.de>
 * @package    TYPO3
 * @subpackage    tx_orginstaller
 * @version 8.0.0
 * @since 8.0.0
 * @internal #t0777
 */
class tx_orginstaller_pi1_fal
{

	public $prefixId = 'tx_orginstaller_pi1_fal'; // Same as class name
	public $scriptRelPath = 'pi1/class.tx_orginstaller_pi1_fal.php'; // Path to this script relative to the extension dir.
	public $extKey = 'org_installer'; // The extension key.
	public $pObj = null;
	private $sysFileStorageUid = 0;
	private $uploadFolder = 'uploads/tx_org/'; // Must correspond with tx_orginstaller_pi1::zz_copyFiles

	/*	 * *********************************************
	 *
	 * Main
	 *
	 * ******************************************** */

	/**
	 * main( )
	 *
	 * @return	void
	 * @access public
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	public function main()
	{
		$this->graphFuncObj = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance( \TYPO3\CMS\Core\Imaging\GraphicalFunctions::class );
		$this->graphFuncObj->init();

		$this->record();
	}

	/*	 * *********************************************
	 *
	 * Records
	 *
	 * ******************************************** */

	/**
	 * record( )
	 *
	 * @return	array		$records : the records
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function record()
	{
		$this->recordSysFileStorage();
		$this->recordSysFile();
		// #i0079, 170417, dwildt, 1-
//		$this->recordSysFileMetadata();
		$this->recordSysFileReference();
	}

	/**
	 * recordSysFile( )
	 *
	 * @return	array		$records : the fieldset records
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile()
	{
		$this->recordSysFile_CalT3Devdays();
		$this->recordSysFile_CalT3Organiser();

		$this->recordSysFile_DownloadsCD1();
		$this->recordSysFile_DownloadsCD2();
		$this->recordSysFile_DownloadsCD3();

		$this->recordSysFile_DownloadsFlyer1();
		$this->recordSysFile_DownloadsFlyer2();

		$this->recordSysFile_DownloadsManual1();
		$this->recordSysFile_DownloadsManual2();
		$this->recordSysFile_DownloadsManual3();

		$this->recordSysFile_HeadquartersNetzmacher();
		$this->recordSysFile_HeadquartersPresident();
		$this->recordSysFile_HeadquartersTYPO3();

		$this->recordSysFile_LocationsNetzmacher();
		$this->recordSysFile_LocationsPresident();
		$this->recordSysFile_LocationsT3Devdays();

		$this->recordSysFile_NewsFlow();
		$this->recordSysFile_NewsOrganiser();

		$this->recordSysFile_StaffUserBobama();
		$this->recordSysFile_StaffUserDwildt();
		$this->recordSysFile_StaffUserSschaffstein();
	}

	/**
	 * recordSysFileMetadata( )
	 *
	 * @return	array		$records : the fieldset records
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata()
	{
		$table = 'sys_file_metadata';
		$records = array();
		$uid = $this->pObj->zz_getMaxDbUid( $table );

		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_CalT3Devdays( $uid );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_CalT3Organiser( $uid );

		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_DownloadsCD1( $uid );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_DownloadsCD2( $uid );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_DownloadsCD3( $uid );

		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_DownloadsFlyer1( $uid );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_DownloadsFlyer2( $uid );

		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_DownloadsManual1( $uid );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_DownloadsManual2( $uid );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_DownloadsManual3( $uid );

		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_HeadquartersNetzmacher( $uid );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_HeadquartersPresident( $uid );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_HeadquartersTYPO3( $uid );

		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_LocationsNetzmacher( $uid );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_LocationsPresident( $uid );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_LocationsT3Devdays( $uid );

		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_NewsFlow( $uid );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_NewsOrganiser( $uid );

		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_StaffUserBobama( $uid );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_StaffUserDwildt( $uid );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileMetadata_StaffUserSschaffstein( $uid );

		$this->sqlInsert( $records, $table, __METHOD__, __LINE__ );
	}

	/**
	 * recordSysFileReference( )
	 *
	 * @return	array		$records : the fieldset records
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference()
	{
		$table = 'sys_file_reference';
		$records = array();
		$uid = $this->pObj->zz_getMaxDbUid( $table );

		$tablefield = 'tx_org_cal.image';
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_CalT3Devdays( $uid, $tablefield );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_CalT3Organiser( $uid, $tablefield );

		$tablefield = 'tx_org_downloads.thumbnail';
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_DownloadsCD1( $uid, $tablefield );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_DownloadsCD2( $uid, $tablefield );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_DownloadsCD3( $uid, $tablefield );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_DownloadsFlyer1( $uid, $tablefield );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_DownloadsFlyer2( $uid, $tablefield );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_DownloadsManual1( $uid, $tablefield );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_DownloadsManual2( $uid, $tablefield );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_DownloadsManual3( $uid, $tablefield );

		$tablefield = 'tx_org_downloads.documents';
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_DownloadsFlyer1( $uid, $tablefield );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_DownloadsFlyer2( $uid, $tablefield );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_DownloadsManual1( $uid, $tablefield );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_DownloadsManual2( $uid, $tablefield );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_DownloadsManual3( $uid, $tablefield );

		$tablefield = 'tx_org_headquarters.image';
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_HeadquartersNetzmacher( $uid, $tablefield );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_HeadquartersPresident( $uid, $tablefield );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_HeadquartersTYPO3( $uid, $tablefield );

		$tablefield = 'tx_org_location.image';
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_LocationsNetzmacher( $uid, $tablefield );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_LocationsPresident( $uid, $tablefield );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_LocationsT3Devdays( $uid, $tablefield );

		$tablefield = 'tx_org_news.image';
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_NewsFlow( $uid, $tablefield );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_NewsOrganiser( $uid, $tablefield );

		$tablefield = 'tx_org_staff.image';
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_StaffUserBobama( $uid, $tablefield );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_StaffUserDwildt( $uid, $tablefield );
		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileReference_StaffUserSschaffstein( $uid, $tablefield );

		$this->sqlInsert( $records, $table, __METHOD__, __LINE__ );
	}

	/**
	 * recordSysFileMetadata_CalT3Devdays( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_CalT3Devdays( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_cal_t3devdays_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_cal_t3devdays_image';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $this->pObj->pi_getLL( 'record_tx_org_t3devdays_imageseo' );
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $this->pObj->pi_getLL( 'record_tx_org_t3devdays_imageseo' );
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_CalT3Organiser( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_CalT3Organiser( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_cal_t3organiser_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_cal_t3organiser_image';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $this->pObj->pi_getLL( 'record_tx_org_t3organiser_imageseo' );
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $this->pObj->pi_getLL( 'record_tx_org_t3organiser_imageseo' );
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_DownloadsCD1( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_DownloadsCD1( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_downloads_cd1_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_downloads_cd1_thumbnail';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $llTitle;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $llTitle;
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_DownloadsCD2( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_DownloadsCD2( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_downloads_cd2_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_downloads_cd2_thumbnail';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $llTitle;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $llTitle;
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_DownloadsCD3( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_DownloadsCD3( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_downloads_cd3_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_downloads_cd3_thumbnail';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $llTitle;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $llTitle;
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_DownloadsFlyer1( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_DownloadsFlyer1( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_downloads_flyer1_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_downloads_flyer1_documents';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $llTitle;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $llTitle;
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_DownloadsFlyer2( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_DownloadsFlyer2( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_downloads_flyer2_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_downloads_flyer2_documents';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $llTitle;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $llTitle;
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_DownloadsManual1( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_DownloadsManual1( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_downloads_manual1_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_downloads_manual1_documents';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $llTitle;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $llTitle;
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_DownloadsManual2( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_DownloadsManual2( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_downloads_manual2_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_downloads_manual2_documents';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $llTitle;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $llTitle;
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_DownloadsManual3( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_DownloadsManual3( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_downloads_manual3_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_downloads_manual3_documents';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $llTitle;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $llTitle;
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_HeadquartersNetzmacher( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_HeadquartersNetzmacher( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_headquarters_netzmacher_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_headquarters_netzmacher_image';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $this->pObj->pi_getLL( 'record_tx_org_headquarters_netzmacher_imageseo' );
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $this->pObj->pi_getLL( 'record_tx_org_headquarters_netzmacher_imageseo' );
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_HeadquartersPresident( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_HeadquartersPresident( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_headquarters_president_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_headquarters_president_image';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $this->pObj->pi_getLL( 'record_tx_org_headquarters_president_imageseo' );
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $this->pObj->pi_getLL( 'record_tx_org_headquarters_president_imageseo' );
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_HeadquartersTYPO3( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_HeadquartersTYPO3( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_headquarters_typo3_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_headquarters_typo3_image';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $this->pObj->pi_getLL( 'record_tx_org_headquarters_typo3_imageseo' );
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $this->pObj->pi_getLL( 'record_tx_org_headquarters_typo3_imageseo' );
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_LocationsNetzmacher( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_LocationsNetzmacher( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_location_netzmacher_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_location_netzmacher_image';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $this->pObj->pi_getLL( 'record_tx_org_location_netzmacher_imageseo' );
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $this->pObj->pi_getLL( 'record_tx_org_location_netzmacher_imageseo' );
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_LocationsPresident( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_LocationsPresident( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_location_president_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_location_president_image';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $this->pObj->pi_getLL( 'record_tx_org_location_president_imageseo' );
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $this->pObj->pi_getLL( 'record_tx_org_location_president_imageseo' );
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_LocationsT3Devdays( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_LocationsT3Devdays( $uid )
	{
		$record = array();
		$llLabel = 'record_tx_org_location_t3devdays_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_location_t3devdays_image';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $this->pObj->pi_getLL( 'record_tx_org_t3devdays_imageseo' );
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $this->pObj->pi_getLL( 'record_tx_org_t3devdays_imageseo' );
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_NewsFlow( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_NewsFlow( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_news_flow_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_news_flow_image';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $this->pObj->pi_getLL( 'record_tx_org_news_flow_imageseo' );
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $this->pObj->pi_getLL( 'record_tx_org_news_flow_imageseo' );
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_NewsOrganiser( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_NewsOrganiser( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_news_organiser_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_news_organiser_image';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $this->pObj->pi_getLL( 'record_tx_org_news_organiser_imageseo' );
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $this->pObj->pi_getLL( 'record_tx_org_news_organiser_imageseo' );
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_StaffUserBobama( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_StaffUserBobama( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_staff_bobama_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_staff_bobama_image';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $this->pObj->pi_getLL( 'record_tx_org_staff_bobama_imageseo' );
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $this->pObj->pi_getLL( 'record_tx_org_staff_bobama_imageseo' );
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_StaffUserDwildt()
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_StaffUserDwildt( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_staff_dwildt_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_staff_dwildt_image';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $this->pObj->pi_getLL( 'record_tx_org_staff_dwildt_imageseo' );
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $this->pObj->pi_getLL( 'record_tx_org_staff_dwildt_imageseo' );
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileMetadata_StaffUserSschaffstein( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileMetadata_StaffUserSschaffstein( $uid )
	{
		$record = array();

		$llLabel = 'record_tx_org_staff_sschaffstein_title';
		$llTitle = $this->pObj->pi_getLL( $llLabel );
		$this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

		$uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

		$llLabel = 'record_tx_org_staff_sschaffstein_image';
		$llImage = $this->pObj->pi_getLL( $llLabel );
		$info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/org_installer/res/files/tx_org/' . $llImage, $info );
//    die();

		$record[ 'uid' ] = $uid;
		$record[ 'alternative' ] = $this->pObj->pi_getLL( 'record_tx_org_staff_sschaffstein_imageseo' );
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'description' ] = $this->pObj->pi_getLL( 'record_tx_org_staff_sschaffstein_imageseo' );
		$record[ 'file' ] = $uidSysFile;
		$record[ 'height' ] = $info[ 1 ];
		$record[ 'title' ] = $llTitle;
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'width' ] = $info[ 0 ];

		return $record;
	}

	/**
	 * recordSysFileReference_CalT3Devdays( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_CalT3Devdays( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_cal_t3devdays_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileReference_CalT3Organiser( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_CalT3Organiser( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_cal_t3organiser_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileReference_DownloadsCD1( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_DownloadsCD1( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_downloads_cd1_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileReference_DownloadsCD2( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_DownloadsCD2( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_downloads_cd2_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileReference_DownloadsCD3( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_DownloadsCD3( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_downloads_cd3_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileReference_DownloadsFlyer1( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_DownloadsFlyer1( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_downloads_flyer1_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileReference_DownloadsFlyer2( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_DownloadsFlyer2( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_downloads_flyer2_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileReference_DownloadsManual1( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_DownloadsManual1( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_downloads_manual1_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileReference_DownloadsManual2( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_DownloadsManual2( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_downloads_manual2_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileReference_DownloadsManual3( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_DownloadsManual3( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_downloads_manual3_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileReference_HeadquartersNetzmacher( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_HeadquartersNetzmacher( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_headquarters_netzmacher_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileReference_HeadquartersPresident( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_HeadquartersPresident( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_headquarters_president_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileReference_HeadquartersTYPO3( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_HeadquartersTYPO3( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_headquarters_typo3_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileReference_LocationsNetzmacher( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_LocationsNetzmacher( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_location_netzmacher_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileReference_LocationsPresident( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_LocationsPresident( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_location_president_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileReference_LocationsT3Devdays( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_LocationsT3Devdays( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_location_t3devdays_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileReference_NewsFlow( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_NewsFlow( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_news_flow_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileReference_NewsOrganiser( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_NewsOrganiser( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_news_organiser_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileReference_StaffUserBobama( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_StaffUserBobama( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_staff_bobama_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;
		return $record;
	}

	/**
	 * recordSysFileReference_StaffUserDwildt()
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_StaffUserDwildt( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_staff_dwildt_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileReference_StaffUserSschaffstein( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileReference_StaffUserSschaffstein( $uid, $tablefield )
	{
		$record = array();

		$llLabel = 'record_tx_org_staff_sschaffstein_title';
		$uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
		$this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
		$uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

		list($tablenames, $fieldname) = explode( '.', $tablefield );

		$record[ 'uid' ] = $uid;
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'fieldname' ] = $fieldname;
		$record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageOrgDataNews_title' ];
		$record[ 'tablenames' ] = $tablenames;
		$record[ 'table_local' ] = 'sys_file';
		$record[ 'tstamp' ] = $this->pObj->time;
		$record[ 'uid_foreign' ] = $uid_foreign;
		$record[ 'uid_local' ] = $uid_local;

		return $record;
	}

	/**
	 * recordSysFileStorage( )
	 *
	 * @return	array		$records : the fieldset records
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileStorage()
	{
		$table = 'sys_file_storage';
		$records = array();
		$uid = $this->pObj->zz_getMaxDbUid( $table );

		$uid = $uid + 1;
		$records[ $uid ] = $this->recordSysFileStorage_Organiser( $uid );

		$this->sqlInsert( $records, $table, __METHOD__, __LINE__ );
	}

	/**
	 * recordSysFileStorage_Organiser( )
	 *
	 * @param	integer		$uid      : uid of the current fieldset
	 * @return	array		$record   : the plugin record
	 * @access private
	 * @version 8.0.0
	 * @since   8.0.0
	 */
	private function recordSysFileStorage_Organiser( $uid )
	{
		$record = array();

		$record[ 'uid' ] = $uid;
		//$record[ 'auto_extract_metadata' ] = 1; // Isn't compatible with TYPO3 6.x
		$record[ 'crdate' ] = $this->pObj->time;
		$record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
		$record[ 'configuration' ] = '<?xml version="1.0" encoding="utf-8" standalone="yes" ?>
<T3FlexForms>
    <data>
        <sheet index="sDEF">
            <language index="lDEF">
                <field index="basePath">
                    <value index="vDEF">uploads/tx_org</value>
                </field>
                <field index="pathType">
                    <value index="vDEF">relative</value>
                </field>
                <field index="caseSensitive">
                    <value index="vDEF">1</value>
                </field>
            </language>
        </sheet>
    </data>
</T3FlexForms>';
		$record[ 'driver' ] = 'Local';
		$record[ 'is_browsable' ] = 1;
		$record[ 'is_online' ] = 1;
		$record[ 'is_public' ] = 1;
		$record[ 'is_writable' ] = 1;
		$record[ 'name' ] = 'Organiser';
		$record[ 'tstamp' ] = $this->pObj->time;

		return $record;
	}

	/**
	 * recordSysFile_CalT3Devdays( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_CalT3Devdays()
	{
		$llTitle = 'record_tx_org_cal_t3devdays_title';
		$llLabel = 'record_tx_org_cal_t3devdays_image';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/**
	 * recordSysFile_CalT3Organiser( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_CalT3Organiser()
	{
		$llTitle = 'record_tx_org_cal_t3organiser_title';
		$llLabel = 'record_tx_org_cal_t3organiser_image';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/**
	 * recordSysFile_DownloadsCD1( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_DownloadsCD1()
	{
		$llTitle = 'record_tx_org_downloads_cd1_title';
		$llLabel = 'record_tx_org_downloads_cd1_thumbnail';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/**
	 * recordSysFile_DownloadsCD2( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_DownloadsCD2()
	{
		$llTitle = 'record_tx_org_downloads_cd2_title';
		$llLabel = 'record_tx_org_downloads_cd2_thumbnail';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/**
	 * recordSysFile_DownloadsCD3( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_DownloadsCD3()
	{
		$llTitle = 'record_tx_org_downloads_cd3_title';
		$llLabel = 'record_tx_org_downloads_cd3_thumbnail';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/**
	 * recordSysFile_DownloadsFlyer1( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_DownloadsFlyer1()
	{
		$llTitle = 'record_tx_org_downloads_flyer1_title';
		$llLabel = 'record_tx_org_downloads_flyer1_documents';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/**
	 * recordSysFile_DownloadsFlyer2( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_DownloadsFlyer2()
	{
		$llTitle = 'record_tx_org_downloads_flyer2_title';
		$llLabel = 'record_tx_org_downloads_flyer2_documents';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/**
	 * recordSysFile_DownloadsManual1( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_DownloadsManual1()
	{
		$llTitle = 'record_tx_org_downloads_manual1_title';
		$llLabel = 'record_tx_org_downloads_manual1_documents';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/**
	 * recordSysFile_DownloadsManual2( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_DownloadsManual2()
	{
		$llTitle = 'record_tx_org_downloads_manual2_title';
		$llLabel = 'record_tx_org_downloads_manual2_documents';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/**
	 * recordSysFile_DownloadsManual3( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_DownloadsManual3()
	{
		$llTitle = 'record_tx_org_downloads_manual3_title';
		$llLabel = 'record_tx_org_downloads_manual3_documents';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/**
	 * recordSysFile_HeadquartersNetzmacher( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_HeadquartersNetzmacher()
	{
		$llTitle = 'record_tx_org_headquarters_netzmacher_title';
		$llLabel = 'record_tx_org_headquarters_netzmacher_image';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/**
	 * recordSysFile_HeadquartersPresident( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_HeadquartersPresident()
	{
		$llTitle = 'record_tx_org_headquarters_president_title';
		$llLabel = 'record_tx_org_headquarters_president_image';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/**
	 * recordSysFile_HeadquartersTYPO3( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_HeadquartersTYPO3()
	{
		$llTitle = 'record_tx_org_headquarters_typo3_title';
		$llLabel = 'record_tx_org_headquarters_typo3_image';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
		$llLabel = 'record_tx_org_headquarters_typo3_image';
	}

	/**
	 * recordSysFile_LocationsNetzmacher( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_LocationsNetzmacher()
	{
		$llTitle = 'record_tx_org_location_netzmacher_title';
		$llLabel = 'record_tx_org_location_netzmacher_image';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/**
	 * recordSysFile_LocationsPresident( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_LocationsPresident()
	{
		$llTitle = 'record_tx_org_location_president_title';
		$llLabel = 'record_tx_org_location_president_image';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/**
	 * recordSysFile_LocationsT3Devdays( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_LocationsT3Devdays()
	{
		$llTitle = 'record_tx_org_location_t3devdays_title';
		$llLabel = 'record_tx_org_location_t3devdays_image';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/**
	 * recordSysFile_NewsFlow( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_NewsFlow()
	{
		$llTitle = 'record_tx_org_news_flow_title';
		$llLabel = 'record_tx_org_news_flow_image';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/**
	 * recordSysFile_NewsOrganiser( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_NewsOrganiser()
	{
		$llTitle = 'record_tx_org_news_organiser_title';
		$llLabel = 'record_tx_org_news_organiser_image';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/**
	 * recordSysFile_StaffUserBobama( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_StaffUserBobama()
	{
		$llTitle = 'record_tx_org_staff_bobama_title';
		$llLabel = 'record_tx_org_staff_bobama_image';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/**
	 * recordSysFile_StaffUserDwildt( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_StaffUserDwildt()
	{
		$llTitle = 'record_tx_org_staff_dwildt_title';
		$llLabel = 'record_tx_org_staff_dwildt_image';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/**
	 * recordSysFile_StaffUserSschaffstein( )
	 *
	 * @return	void
	 * @access private
	 * @version 8.0.21
	 * @since   8.0.0
	 */
	private function recordSysFile_StaffUserSschaffstein()
	{
		$llTitle = 'record_tx_org_staff_sschaffstein_title';
		$llLabel = 'record_tx_org_staff_sschaffstein_image';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
	}

	/*	 * *********************************************
	 *
	 * Sql
	 *
	 * ******************************************** */

	/**
	 * sqlInsert( )
	 *
	 * @param	array		$records : TypoScript records for pages
	 * @param	[type]		$table: ...
	 * @return	void
	 * @access private
	 * @version 6.0.0
	 * @since   8.0.0
	 */
	private function sqlInsert( $records, $table, $method = NULL, $line = NULL )
	{
		if( empty( $method ) )
		{
			$method = __METHOD__;
		}
		if( empty( $line ) )
		{
			$line = __LINE__;
		}
		foreach( $records as $record )
		{
			//var_dump($GLOBALS['TYPO3_DB']->INSERTquery( $table, $record ) );
			$GLOBALS[ 'TYPO3_DB' ]->exec_INSERTquery( $table, $record );
			$error = $GLOBALS[ 'TYPO3_DB' ]->sql_error();

			if( $error )
			{
				$query = $GLOBALS[ 'TYPO3_DB' ]->INSERTquery( $table, $record );
//        // #61666, 141003, dwildt
//        $prompt = 'SQL-ERROR<br />' . PHP_EOL .
//          'query: ' . $query . '.<br />' . PHP_EOL .
//          'error: ' . $error . '.<br />' . PHP_EOL .
//          'Sorry for the trouble.<br />' . PHP_EOL .
//          'TYPO3-Organiser Installer<br />' . PHP_EOL .
//          $method . ' (' . $line . ')';
				$prompt = '<div style="border:1em solid red;margin:1em;padding:2em;">' . PHP_EOL
								. 'SQL-ERROR<br />' . PHP_EOL
								. 'query: ' . $query . '.<br />' . PHP_EOL
								. 'error: ' . $error . '.<br />' . PHP_EOL
								. 'Sorry for the trouble.<br />' . PHP_EOL
								. 'TYPO3-Organiser Installer<br />' . PHP_EOL
								. $method . ' (' . $line . ')' . PHP_EOL
								. '</div>' . PHP_EOL
								. '<div style="border:1em solid blue;margin:1em;padding:2em;">' . PHP_EOL
								. 'HELP<br />' . PHP_EOL
								. '1. Please save the installer plugin again. Probably the SQL error is solved.<br />' . PHP_EOL
								. '2. Reload this page.<br />' . PHP_EOL
								. '3. If error occurs again, please update your database. <br />' . PHP_EOL
								. '   See: System > Install > Import action > Database analyzer [Compare current database with spezifications]<br />' . PHP_EOL
								. '4. Remove installed pages.<br />' . PHP_EOL
								. '5. Reload this page.' . PHP_EOL
								. '</div>' . PHP_EOL
								. '<pre>' . PHP_EOL
								. var_export( $records, TRUE )
								. '</pre>' . PHP_EOL
				;
				die( $prompt );
			}

			// CONTINUE : pid is empty, no prompt
			if( empty( $record[ 'pid' ] ) )
			{
				continue;
			}
			// CONTINUE : pid is empty, no prompt
			// prompt
			$pageTitle = $this->pObj->arr_pageTitles[ $record[ 'pid' ] ];
			$pageTitle = $this->pObj->pi_getLL( $pageTitle );

			$title = $record[ 'title' ];
			if( empty( $title ) )
			{
				$title = $record[ 'header' ];
			}
			if( empty( $title ) )
			{
				$title = $record[ 'name' ];
			}
			$marker[ '###TITLE###' ] = $title;
			$marker[ '###TABLE###' ] = $this->pObj->pi_getLL( $table, '<i>' . $table . '</i>' );
			$marker[ '###TITLE_PID###' ] = '"' . $pageTitle . '" (uid ' . $record[ 'pid' ] . ')';
			$prompt = '
        <p>
          ' . $this->pObj->arr_icons[ 'ok' ] . ' ' . $this->pObj->pi_getLL( 'record_create_prompt' ) . '
        </p>';
			$prompt = $this->pObj->cObj->substituteMarkerArray( $prompt, $marker );
			$this->pObj->arrReport[] = $prompt;
			// prompt
		}
	}

	/**
	 * zzSysFileInsert( )
	 *
	 * @param	string		$file
	 * @return	integer		Insert uid from sql database
	 * @access private
	 * @internal #i0079
	 * @version 8.0.21
	 * @since   8.0.21
	 */
	private function zzSysFileInsert( $file )
	{
		$pathAbs = PATH_site . $this->uploadFolder . $file;
		if( !file_exists( $pathAbs ) )
		{
			$prompt = 'FATAL ERROR! File does not exist: ' . $pathAbs;
			die( $prompt );
		}

		$identifier = PathUtility::getRelativePath( PATH_site, PATH_site . $this->uploadFolder ) . $file;
		$fileObject = ResourceFactory::getInstance()->getFileObjectByStorageAndIdentifier( $this->sysFileStorageUid, $identifier );
		$uid = $fileObject->getUid();
		return $uid;
	}

}

if( defined( 'TYPO3_MODE' ) && $TYPO3_CONF_VARS[ TYPO3_MODE ][ 'XCLASS' ][ 'ext/org_installer/pi1/class.tx_orginstaller_pi1_org.php' ] )
{
	include_once($TYPO3_CONF_VARS[ TYPO3_MODE ][ 'XCLASS' ][ 'ext/org_installer/pi1/class.tx_orginstaller_pi1_org.php' ]);
}